@@ -80,6 +80,10 @@ class Client(
     :param VERIFY_WEBUI_CERTIFICATE: Set to False to skip verify certificate for HTTPS connections;
         for instance, if the connection is using a self-signed certificate. Not setting this to False for self-signed
         certs will cause a APIConnectionError exception to be raised.
+    :param EXTRA_HEADERS: Dictionary of HTTP Headers to include in all requests made to qBittorrent.
+    :param FORCE_SCHEME_FROM_HOST: If a scheme (i.e. http or https) is specifed in host, it will be used regardless of
+        whether qBittorrent is configured for HTTP or HTTPS communication. Normally, this client will attempt to
+        determine which scheme qBittorrent is actually listening on...but this can cause problems in rare cases.
     :param RAISE_NOTIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS: Some Endpoints may not be implemented in older
         versions of qBittorrent. Setting this to True will raise a NotImplementedError instead of just returning None.
     :param DISABLE_LOGGING_DEBUG_OUTPUT: Turn off debug output from logging for this package as well as Requests & urllib3.
